<?php
/*
Plugin Name: UXWizz
Plugin URI: https://www.uxwizz.com
Description: Self-hosted analytics platform with heatmaps, full session recordings. All data is stored in the local WordPress database. No 3rd parties.
Author: tips4design
Version: 6.0.3
Author URI: https://twitter.com/XCSme
 */

//********************//

global $wpdb;
$UST_version = '6.0.3';

function ust_isFuncEnabled($func) {
    return is_callable($func) && false === stripos(ini_get('disable_functions'), $func);
}

function userTrack_activation() {
    // Necessary to save settings etc.
    if (ust_isFuncEnabled('chmod')) {
        try {chmod(__DIR__ . "/userTrack/server/ust.min.js", 0777);} catch (Exception $e) {}
    }
    if (ust_isFuncEnabled('shell_exec')) {
        try {shell_exec("chmod -R 777 " . __DIR__ . "/userTrack/server/ust.min.js");} catch (Exception $e) {}
    }
}
register_activation_hook(__FILE__, 'userTrack_activation');

/*** Sidebar menu buttons ***/
function userTrack_theme_options_panel() {
    add_menu_page('UXWizz Options', 'UXWizz', 'edit_posts', 'UXWizz', 'userTrack_plugin_options', plugin_dir_url(__FILE__) . 'userTrack/favicon.55ca7136.ico');
    add_submenu_page('UXWizz', 'Tracking settings', 'Tracking settings', 'edit_posts', 'theme-op-settings', 'userTrack_wps_theme_func_settings');
}
add_action('admin_menu', 'userTrack_theme_options_panel');

/*** Drop tables on plugin uninstall ***/
function userTrack_pluginUninstall() {
    global $wpdb;

    //Delete any options thats stored also?
    delete_option('ust_checkfield');

    // Drop all tables
    $wpdb->query("SET FOREIGN_KEY_CHECKS=0;");
    $wpdb->query("DROP TABLE IF EXISTS ust_meta, ust_access, ust_movements, ust_limits, ust_ab, ust_user_client_ip_label, ust_user_client_watched, ust_records, ust_partials, ust_clicks, ust_client_tag, ust_client_event, ust_clientpage, ust_clients, ust_users;");
    $wpdb->query("SET FOREIGN_KEY_CHECKS=1;");
}
register_uninstall_hook(__FILE__, 'userTrack_pluginUninstall');

$defaultCheckboxOptions = array(
    'all' => 1,
    'tracked_admins' => 1,
    'tracked_logged_in' => 1,
    'tracked_visitors' => 1,
);
/*** Settings for which Tracking settings ***/
function userTrack_wps_theme_func_settings() {
    global $defaultCheckboxOptions;
    error_reporting(E_ALL);
    ini_set('display_errors', 1);

    if (isset($_REQUEST['ust_nonce']) && wp_verify_nonce($_REQUEST['ust_nonce'], 'ust_save_checkboxes')) {
        $newCheckboxes = isset($_POST['ust_checkfield']) ? $_POST['ust_checkfield'] : $defaultCheckboxOptions;
        update_option('ust_checkfield', $newCheckboxes);
        $ust_checkfield = $newCheckboxes;
    } else {
        $ust_checkfield = get_option('ust_checkfield', $defaultCheckboxOptions); //get_post_meta($post->ID, "ust_checkfield", true);
    }
    $args = array('posts_per_page' => -1, 'post_type' => array('post', 'page'));
    $pages = get_posts($args);
    ?>

        <div class="wrap"><div id="icon-options-general" class="icon32"><br></div>
        <form action="" method="post" style="margin-left:5px;">
        <h1>UXWizz tracking settings</h1>

        <hr/>
        <h1>Tracked user categories</h1>
        <p>Enable or disable tracking for users based on their log-in state.</p>

        <input
            id="ust_tracked_users_visitors" type="checkbox" name="ust_checkfield[tracked_visitors]" value="1"
            <?php checked(@$ust_checkfield['tracked_visitors'], 1);?>
        />
        <label for="ust_tracked_users_visitors">Visitors</label><br/>

        <input id="ust_tracked_users_logged_in" type="checkbox" name="ust_checkfield[tracked_logged_in]" value="1"
            <?php checked(@$ust_checkfield['tracked_logged_in'], 1);?>
        />
        <label for="ust_tracked_users_logged_in">Logged in users</label><br/>

        <input id="ust_tracked_users_admins" type="checkbox" name="ust_checkfield[tracked_admins]" value="1"
            <?php checked(@$ust_checkfield['tracked_admins'], 1);?>
        />
        <label for="ust_tracked_users_admins">Admins</label><br/>

        <hr/>
        <h1>Tracked pages</h1>
        <?php wp_nonce_field('ust_save_checkboxes', 'ust_nonce');?>
        <input id="all_pages" type="checkbox" name="ust_checkfield[all]" value="1"
            <?php checked(@$ust_checkfield['all'], 1);?>
        />
        <label for="all_pages" style="font-weight: bold; color: #752497;">ALL PAGES EXCEPT THE SELECTED ONES</label><br>
        <span style="padding-left: 24px;">
          <?php
if (!@$ust_checkfield['all']) {
        echo 'When this is unchecked, the tracker will on be included on the selected pages.';
    } else {
        echo 'When this is checked, the tracker will be included on all pages except the selected ones.';
    }
    ?>
        </span>
        <br/>

        <input id="page_home" type="checkbox" name="ust_checkfield[home]" value="1"
            <?php checked(@$ust_checkfield['home'], 1);?>
        />
        <label for="page_home">Posts list page</label> <br>

        <?php foreach ($pages as $page) {?>
            <input id="page_<?php echo $page->ID; ?>" type="checkbox" name="ust_checkfield[<?php echo $page->ID; ?>]" value="1"
                 <?php checked(@$ust_checkfield[$page->ID], 1);?>
            />
            <label for="page_<?php echo $page->ID; ?>"><?php echo $page->post_title; ?></label> <br>
        <?php }?>
        <br><br>
        <input type="submit" value="Save" class="button button-primary" id="submit" name="submit">
        </form></div>
        <?php
}

function userTrack_plugin_options() {
    ?>

<div style="text-align: center;">
    <a href="<?php echo plugins_url('/wp-usertrack/userTrack/'); ?>" style="margin: 50px auto 10px auto;display: inline-block;font-size: 25px;padding: 20px;font-weight: bold;background-color: #6c0f97;color: white;text-decoration: none;border-radius: 5px;" target="_blank">
        Click here to open UXWizz in a new tab.
    </a>
    <div>Viewing UXWizz in a separate tab increases the screen size available to display graphs and other data.</div><br/>
    <div>Note: <b>The tracking script is automatically added to all pages in the "Tracking settings" UXWizz menu on the left.</b></div>
</div>
<?php
}

function userTrack_isCurrentUserTracked() {
    global $defaultCheckboxOptions;
    $ust_checkfield = (array) get_option('ust_checkfield', $defaultCheckboxOptions);
    $dontTrack = false;

    if (!is_user_logged_in()) {
        if (!@$ust_checkfield['tracked_visitors']) {
            $dontTrack = true;
        }
    } else {
        $is_admin = current_user_can('manage_options');
        if ($is_admin) {
            if (!@$ust_checkfield['tracked_admins']) {
                $dontTrack = true;
            }
        } else {
            if (!@$ust_checkfield['tracked_logged_in']) {
                $dontTrack = true;
            }
        }
    }

    return $dontTrack;
}

function addUserTrackScript() {
    global $UST_version;
    wp_register_script('ust-tracker-inline', '');
    wp_enqueue_script('ust-tracker-inline');

    $dontTrackString = userTrack_isCurrentUserTracked() ? 'UST_NO_TRACK = true;' : '';
    wp_add_inline_script('ust-tracker-inline', "$dontTrackString UST_CT = [];UST = { s: Date.now(), addTag: function(tag) { UST_CT.push(tag) } };");
    wp_register_script('ust-tracker', plugins_url('/userTrack/server/ust.min.js?v=' . $UST_version, __FILE__));
    wp_enqueue_script('ust-tracker');
}

/*** Add the tracker to the checked options ***/
function ust_head() {
    if (is_admin()) {
        return;
    }

    global $defaultCheckboxOptions;
    $ust_checkfield = (array) get_option('ust_checkfield', $defaultCheckboxOptions);
    $trackSelected = !@$ust_checkfield['all'];

    // Include the tracker on selected pages (or not selected if inverse mode)
    if (is_singular()) {
        if ((@$ust_checkfield[get_the_ID()] == 1) === $trackSelected) {addUserTrackScript();}
    } else if (is_home()) {
        if ((@$ust_checkfield['home'] == 1) === $trackSelected) {addUserTrackScript();}

    }
}
add_action('wp_head', 'ust_head');
?>